def calculate_handling_costs(dict_ac_data, dict_operating_costs, runtime_output):
    """Calculate annual handling costs.

    Handling charges include charges for loading and unloading, use of terminals and passenger boarding bridges,
    security checks, and ground energy supply. The annual handling costs depend on the payload mass and the number of
    flights per year.

    This function adds the 'handling_costs' dict to the 'dict_operating_costs' that contains the following parameters:
        - float handling_costs: Handling costs per year in EUR

    :param dict dict_ac_data: Dict containing parameters and values from aircraft exchange and module config file
    :param dict dict_operating_costs: Dict containing parameters from cost estimation calculation
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict dict_operating_costs: Dict containing parameters from cost estimation calculation
    """

    # Extract necessary variables from 'dict_ac_data'.
    fees_handling = dict_ac_data['fees_handling']
    m_payload = dict_ac_data['m_payload']
    # Extract necessary values from 'dict_operating_costs'.
    n_annual_flights = dict_operating_costs['dependent_parameter']['flights_per_year']

    # Calculate handling costs.
    handling_costs = m_payload * fees_handling * n_annual_flights

    # Print.
    runtime_output.print('Handling costs (per year): ' + f"{int(handling_costs):,}" + ' €')

    # Prepare output data.
    dict_operating_costs['handling_costs'] = {}
    dict_operating_costs['handling_costs']['handling_costs'] = handling_costs

    return dict_operating_costs
